==> jc-1.4.0.tar.gz: polyglot/frontend/OutputPass.h <==
// public class polyglot.frontend.OutputPass

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4dca5983f7072958 polyglot_frontend_AbstractPass
// @dep_class 6aa75a8eea69c49f polyglot_frontend_OutputPass

// header file dependencies
// @dep_header polyglot_frontend_AbstractPass

#include "polyglot/frontend/AbstractPass.h"

#ifndef _JC_polyglot_frontend_OutputPass_H_
#define _JC_polyglot_frontend_OutputPass_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_polyglot_frontend_Job$object;
struct _jc_polyglot_frontend_Pass__24ID$object;
struct _jc_polyglot_visit_Translator$object;

// Typedefs
typedef struct _jc_polyglot_frontend_OutputPass$sub_refs	_jc_polyglot_frontend_OutputPass$sub_refs;
typedef struct _jc_polyglot_frontend_OutputPass$sub_nonrefs	_jc_polyglot_frontend_OutputPass$sub_nonrefs;
typedef struct _jc_polyglot_frontend_OutputPass$refs	_jc_polyglot_frontend_OutputPass$refs;
typedef struct _jc_polyglot_frontend_OutputPass$nonrefs	_jc_polyglot_frontend_OutputPass$nonrefs;
typedef struct _jc_polyglot_frontend_OutputPass$object	_jc_polyglot_frontend_OutputPass$object;

typedef const struct _jc_polyglot_frontend_OutputPass$vmethods	_jc_polyglot_frontend_OutputPass$vmethods;
typedef const struct _jc_polyglot_frontend_OutputPass$vtable	_jc_polyglot_frontend_OutputPass$vtable;
typedef const struct _jc_polyglot_frontend_OutputPass$vtype	_jc_polyglot_frontend_OutputPass$vtype;

// Constructors
extern void _jc_polyglot_frontend_OutputPass$method$_init$682210bf4e4766e0(_jc_env *, struct _jc_polyglot_frontend_OutputPass$object *, struct _jc_polyglot_frontend_Pass__24ID$object *, struct _jc_polyglot_frontend_Job$object *, struct _jc_polyglot_visit_Translator$object *);

// Virtual methods
extern jboolean _jc_polyglot_frontend_OutputPass$method$run$1ec62afce18bd5ee(_jc_env *, struct _jc_polyglot_frontend_OutputPass$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_frontend_OutputPass$method_info$run$1ec62afce18bd5ee;

// Virtual methods structure
struct _jc_polyglot_frontend_OutputPass$vmethods {
	jboolean	(*run$1ec62afce18bd5ee)(_jc_env *, struct _jc_polyglot_frontend_OutputPass$object *);
};

// Vtable
struct _jc_polyglot_frontend_OutputPass$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_frontend_AbstractPass$vmethods	polyglot_frontend_AbstractPass;
	_jc_polyglot_frontend_OutputPass$vmethods	polyglot_frontend_OutputPass;
};

// Vtype
struct _jc_polyglot_frontend_OutputPass$vtype {
	_jc_type			type;
	_jc_polyglot_frontend_OutputPass$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_frontend_OutputPass$sub_refs {
	struct _jc_polyglot_frontend_Job$object	*job;
	struct _jc_polyglot_visit_Translator$object	*translator;
};

// Reference instance fields (object)
struct _jc_polyglot_frontend_OutputPass$refs {
    _jc_polyglot_frontend_OutputPass$sub_refs	polyglot_frontend_OutputPass;
    _jc_polyglot_frontend_AbstractPass$sub_refs	polyglot_frontend_AbstractPass;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_frontend_OutputPass$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_frontend_OutputPass$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_frontend_AbstractPass$sub_nonrefs	polyglot_frontend_AbstractPass;
    _jc_polyglot_frontend_OutputPass$sub_nonrefs	polyglot_frontend_OutputPass;
};

// Object instance structure
struct _jc_polyglot_frontend_OutputPass$object {
	_jc_polyglot_frontend_OutputPass$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_frontend_OutputPass$vtype	*vtype;
	_jc_polyglot_frontend_OutputPass$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_frontend_OutputPass$vtype _jc_polyglot_frontend_OutputPass$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_frontend_OutputPass, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_frontend_OutputPass$class_object;

#endif	/* _JC_polyglot_frontend_OutputPass_H_ */

==> jc-1.4.6.tar.gz: polyglot/frontend/OutputPass.h <==
// public class polyglot.frontend.OutputPass

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4dca5983f7072958 polyglot_frontend_AbstractPass
// @dep_class 6aa75a8eea69c49f polyglot_frontend_OutputPass

// header file dependencies
// @dep_header polyglot_frontend_AbstractPass

#include "polyglot/frontend/AbstractPass.h"

#ifndef _JC_polyglot_frontend_OutputPass_H_
#define _JC_polyglot_frontend_OutputPass_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_polyglot_frontend_Job$object;
struct _jc_polyglot_frontend_Pass__24ID$object;
struct _jc_polyglot_visit_Translator$object;

// Typedefs
typedef struct _jc_polyglot_frontend_OutputPass$sub_refs	_jc_polyglot_frontend_OutputPass$sub_refs;
typedef struct _jc_polyglot_frontend_OutputPass$sub_nonrefs	_jc_polyglot_frontend_OutputPass$sub_nonrefs;
typedef struct _jc_polyglot_frontend_OutputPass$refs	_jc_polyglot_frontend_OutputPass$refs;
typedef struct _jc_polyglot_frontend_OutputPass$nonrefs	_jc_polyglot_frontend_OutputPass$nonrefs;
typedef struct _jc_polyglot_frontend_OutputPass$object	_jc_polyglot_frontend_OutputPass$object;

typedef const struct _jc_polyglot_frontend_OutputPass$vmethods	_jc_polyglot_frontend_OutputPass$vmethods;
typedef const struct _jc_polyglot_frontend_OutputPass$vtable	_jc_polyglot_frontend_OutputPass$vtable;
typedef const struct _jc_polyglot_frontend_OutputPass$vtype	_jc_polyglot_frontend_OutputPass$vtype;

// Constructors
extern void _jc_polyglot_frontend_OutputPass$method$_init$682210bf4e4766e0(_jc_env *, struct _jc_polyglot_frontend_OutputPass$object *, struct _jc_polyglot_frontend_Pass__24ID$object *, struct _jc_polyglot_frontend_Job$object *, struct _jc_polyglot_visit_Translator$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_polyglot_frontend_OutputPass$method$run$1ec62afce18bd5ee(_jc_env *, struct _jc_polyglot_frontend_OutputPass$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_frontend_OutputPass$method_info$run$1ec62afce18bd5ee;

// Virtual methods structure
struct _jc_polyglot_frontend_OutputPass$vmethods {
	jboolean	(*run$1ec62afce18bd5ee)(_jc_env *, struct _jc_polyglot_frontend_OutputPass$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_frontend_OutputPass$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_frontend_AbstractPass$vmethods	polyglot_frontend_AbstractPass;
	_jc_polyglot_frontend_OutputPass$vmethods	polyglot_frontend_OutputPass;
};

// Vtype
struct _jc_polyglot_frontend_OutputPass$vtype {
	_jc_type			type;
	_jc_polyglot_frontend_OutputPass$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_frontend_OutputPass$sub_refs {
	struct _jc_polyglot_frontend_Job$object	*job;
	struct _jc_polyglot_visit_Translator$object	*translator;
};

// Reference instance fields (object)
struct _jc_polyglot_frontend_OutputPass$refs {
    _jc_polyglot_frontend_OutputPass$sub_refs	polyglot_frontend_OutputPass;
    _jc_polyglot_frontend_AbstractPass$sub_refs	polyglot_frontend_AbstractPass;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_frontend_OutputPass$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_frontend_OutputPass$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_frontend_AbstractPass$sub_nonrefs	polyglot_frontend_AbstractPass;
    _jc_polyglot_frontend_OutputPass$sub_nonrefs	polyglot_frontend_OutputPass;
};

// Object instance structure
struct _jc_polyglot_frontend_OutputPass$object {
	_jc_polyglot_frontend_OutputPass$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_frontend_OutputPass$vtype	*vtype;
	_jc_polyglot_frontend_OutputPass$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_frontend_OutputPass$vtype _jc_polyglot_frontend_OutputPass$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_frontend_OutputPass, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_frontend_OutputPass$class_object;

#endif	/* _JC_polyglot_frontend_OutputPass_H_ */
